Skip to main contentCrate foxtive_cron
Source pub use builder::CronExpression;
- builder
- contracts
- Cron
- An asynchronous job scheduler that runs registered jobs based on cron expressions.
- CronBuilder
- A builder for the
Cron scheduler. - FnJob
- A lightweight, closure-based implementation of
JobContract. - JobItem
- An internal wrapper around a
JobContract that caches the parsed schedule
and exposes helper methods used by the scheduler.
- CronError
- Custom error types for the
foxtive-cron library.
- CronResult
- A type alias for results returned by cron jobs, using
CronError.